==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PriceChannelOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialOverlayDescriptionMetadata } from "./FinancialOverlayDescriptionMetadata";
import { PriceChannelOverlayDescription } from "./PriceChannelOverlayDescription";
/**
 * @hidden
 */
export let PriceChannelOverlayDescriptionMetadata = /*@__PURE__*/ (() => {
    class PriceChannelOverlayDescriptionMetadata extends Base {
        static b(a) {
            if (PriceChannelOverlayDescriptionMetadata.a == null) {
                PriceChannelOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PriceChannelOverlayDescriptionMetadata.c(PriceChannelOverlayDescriptionMetadata.a);
            }
            if (a.k(PriceChannelOverlayDescriptionMetadata.a)) {
                return;
            }
            a.aa(PriceChannelOverlayDescriptionMetadata.a);
        }
        static c(a) {
            FinancialOverlayDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            PriceChannelOverlayDescriptionMetadata.b(a);
            a.ac("PriceChannelOverlay", () => new PriceChannelOverlayDescription());
            a.ab("PriceChannelOverlay", PriceChannelOverlayDescriptionMetadata.a);
        }
    }
    PriceChannelOverlayDescriptionMetadata.$t = /*@__PURE__*/ markType(PriceChannelOverlayDescriptionMetadata, 'PriceChannelOverlayDescriptionMetadata');
    PriceChannelOverlayDescriptionMetadata.a = null;
    return PriceChannelOverlayDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/PriceChannelOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialOverlayDescriptionMetadata } from "./FinancialOverlayDescriptionMetadata";
import { PriceChannelOverlayDescription } from "./PriceChannelOverlayDescription";
/**
 * @hidden
 */
export let PriceChannelOverlayDescriptionMetadata = /*@__PURE__*/ (() => {
    class PriceChannelOverlayDescriptionMetadata extends Base {
        static b(a) {
            if (PriceChannelOverlayDescriptionMetadata.a == null) {
                PriceChannelOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PriceChannelOverlayDescriptionMetadata.c(PriceChannelOverlayDescriptionMetadata.a);
            }
            if (a.k(PriceChannelOverlayDescriptionMetadata.a)) {
                return;
            }
            a.ac(PriceChannelOverlayDescriptionMetadata.a);
        }
        static c(a) {
            FinancialOverlayDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            PriceChannelOverlayDescriptionMetadata.b(a);
            a.ae("PriceChannelOverlay", () => new PriceChannelOverlayDescription());
            a.ad("PriceChannelOverlay", PriceChannelOverlayDescriptionMetadata.a);
        }
    }
    PriceChannelOverlayDescriptionMetadata.$t = /*@__PURE__*/ markType(PriceChannelOverlayDescriptionMetadata, 'PriceChannelOverlayDescriptionMetadata');
    PriceChannelOverlayDescriptionMetadata.a = null;
    return PriceChannelOverlayDescriptionMetadata;
})();
